grib2io.tables.section4_discipline3 API documentation

# grib2io.tables.section4_discipline3

View Source

      1table_4_2_3_0  = {
      2'0':['Scaled Radiance','Numeric','SRAD'],
      3'1':['Scaled Albedo','Numeric','SALBEDO'],
      4'2':['Scaled Brightness Temperature','Numeric','SBTMP'],
      5'3':['Scaled Precipitable Water','Numeric','SPWAT'],
      6'4':['Scaled Lifted Index','Numeric','SLFTI'],
      7'5':['Scaled Cloud Top Pressure','Numeric','SCTPRES'],
      8'6':['Scaled Skin Temperature','Numeric','SSTMP'],
      9'7':['Cloud Mask','See Table 4.217','CLOUDM'],
     10'8':['Pixel scene type','See Table 4.218','PIXST'],
     11'9':['Fire Detection Indicator','See Table 4.223','FIREDI'],
     12'10-191':['Reserved','unknown','unknown'],
     13'192-254':['Reserved for Local Use','unknown','unknown'],
     14'255':['Missing','unknown','unknown'],
     15}
     16table_4_2_3_1  = {
     17'0':['Estimated Precipitation','kg m-2','ESTP'],
     18'1':['Instantaneous Rain Rate','kg m-2 s-1','IRRATE'],
     19'2':['Cloud Top Height','m','CTOPH'],
     20'3':['Cloud Top Height Quality Indicator','Code table 4.219','CTOPHQI'],
     21'4':['Estimated u-Component of Wind','m s-1','ESTUGRD'],
     22'5':['Estimated v-Component of Wind','m s-1','ESTVGRD'],
     23'6':['Number Of Pixels Used','Numeric','NPIXU'],
     24'7':['Solar Zenith Angle','°','SOLZA'],
     25'8':['Relative Azimuth Angle','°','RAZA'],
     26'9':['Reflectance in 0.6 Micron Channel','%','RFL06'],
     27'10':['Reflectance in 0.8 Micron Channel','%','RFL08'],
     28'11':['Reflectance in 1.6 Micron Channel','%','RFL16'],
     29'12':['Reflectance in 3.9 Micron Channel','%','RFL39'],
     30'13':['Atmospheric Divergence','s-1','ATMDIV'],
     31'14':['Cloudy Brightness Temperature','K','CBTMP'],
     32'15':['Clear Sky Brightness Temperature','K','CSBTMP'],
     33'16':['Cloudy Radiance (with respect to wave number)','W m-1 sr-1','CLDRAD'],
     34'17':['Clear Sky Radiance (with respect to wave number)','W m-1 sr-1','CSKYRAD'],
     35'18':['Reserved','unknown','unknown'],
     36'19':['Wind Speed','m s-1','WINDS'],
     37'20':['Aerosol Optical Thickness at 0.635 µm','unknown','AOT06'],
     38'21':['Aerosol Optical Thickness at 0.810 µm','unknown','AOT08'],
     39'22':['Aerosol Optical Thickness at 1.640 µm','unknown','AOT16'],
     40'23':['Angstrom Coefficient','unknown','ANGCOE'],
     41'24-26':['Reserved','unknown','unknown'],
     42'27':['Bidirectional Reflecance Factor','Numeric','BRFLF'],
     43'28':['Brightness Temperature','K','SPBRT'],
     44'29':['Scaled Radiance','Numeric','SCRAD'],
     45'30':['Reflectance in 0.4 Micron Channel','%','RFL04'],
     46'31':['Cloudy reflectance','%','CLDREF'],
     47'32':['Clear reflectance','%','CLRREF'],
     48'33-97':['Reserved','unknown','unknown'],
     49'98':['Correlation coefficient between MPE rain rates for the co-located IR data and the microwave data rain rates','Numeric','CCMPEMRR'],
     50'99':['Standard deviation between MPE rain rates for the co-located IR data and the microwave data rain rates','Numeric','SDMPEMRR'],
     51'100-191':['Reserved','unknown','unknown'],
     52'192-254':['Reserved for Local Use','unknown','unknown'],
     53'192':['Scatterometer Estimated U Wind Component','m s-1','USCT'],
     54'193':['Scatterometer Estimated V Wind Component','m s-1','VSCT'],
     55'194':['Scatterometer Wind Quality','unknown','SWQI'],
     56'255':['Missing','unknown','unknown'],
     57}
     58table_4_2_3_2  = {
     59'0':['Clear Sky Probability','%','CSKPROB'],
     60'1':['Cloud Top Temperature','K','CTOPTMP'],
     61'2':['Cloud Top Pressure','Pa','CTOPRES'],
     62'3':['Cloud Type','See Table 4.218','CLDTYPE'],
     63'4':['Cloud Phase','See Table 4.218','CLDPHAS'],
     64'5':['Cloud Optical Depth','Numeric','CLDODEP'],
     65'6':['Cloud Particle Effective Radius','m','CLDPER'],
     66'7':['Cloud Liquid Water Path','kg m-2','CLDLWP'],
     67'8':['Cloud Ice Water Path','kg m-2','CLDIWP'],
     68'9':['Cloud Albedo','Numeric','CLDALB'],
     69'10':['Cloud Emissivity','Numeric','CLDEMISS'],
     70'11':['Effective Absorption Optical Depth Ratio','Numeric','EAODR'],
     71'12-29':['Reserved','unknown','unknown'],
     72'30':['Measurement cost','Numeric','MEACST'],
     73'31':['Upper layer cloud optical depth (see Note)','Numeric','unknown'],
     74'32':['Upper layer cloud top pressure (see Note)','Pa','unknown'],
     75'33':['Upper layer cloud effective radius (see Note)','m','unknown'],
     76'34':['Error in upper layer cloud optical depth(se Note)','Numeric','unknown'],
     77'35':['Error in upper layer cloud top pressure (see Note)','Pa','unknown'],
     78'36':['Error in upper layer cloud effective radius (see Note)','m','unknown'],
     79'37':['Lower layer cloud optical depth (see Note)','Numeric','unknown'],
     80'38':['Lower layer cloud top pressure (see Note)','Pa','unknown'],
     81'39':['Error in lower layer cloud optical depth (see Note)','Numeric','unknown'],
     82'40':['Error in lower layer cloud top pressure (see Note)','Pa','unknown'],
     83'41-191':['Reserved','unknown','unknown'],
     84'192-254':['Reserved for Local Use','unknown','unknown'],
     85'255':['Missing','unknown','unknown'],
     86}
     87table_4_2_3_3  = {
     88'0':['Probability of Encountering Marginal Visual Flight Rules Conditions','%','PBMVFRC'],
     89'1':['Probability of Encountering Low Instrument Flight Rules Conditions','%','PBLIFRC'],
     90'2':['Probability of Encountering Instrument Flight Rules Conditions','%','PBINFRC'],
     91'3-191':['Reserved','unknown','unknown'],
     92'192-254':['Reserved for Local Use','unknown','unknown'],
     93'255':['Missing','unknown','unknown'],
     94}
     95table_4_2_3_4  = {
     96'0':['Volcanic Ash Probability','%','VOLAPROB'],
     97'1':['Volcanic Ash Cloud Top Temperature','K','VOLACDTT'],
     98'2':['Volcanic Ash Cloud Top Pressure','Pa','VOLACDTP'],
     99'3':['Volcanic Ash Cloud Top Height','m','VOLACDTH'],
    100'4':['Volcanic Ash Cloud Emissity','Numeric','VOLACDEM'],
    101'5':['Volcanic Ash Effective Absorption Depth Ratio','Numeric','VOLAEADR'],
    102'6':['Volcanic Ash Cloud Optical Depth','Numeric','VOLACDOD'],
    103'7':['Volcanic Ash Column Density','kg m-2','VOLACDEN'],
    104'8':['Volcanic Ash Particle Effective Radius','m','VOLAPER'],
    105'9-191':['Reserved','unknown','unknown'],
    106'192-254':['Reserved for Local Use','unknown','unknown'],
    107'255':['Missing','unknown','unknown'],
    108}
    109table_4_2_3_5  = {
    110'0':['Interface Sea-Surface Temperature','K','ISSTMP'],
    111'1':['Skin Sea-Surface Temperature','K','SKSSTMP'],
    112'2':['Sub-Skin Sea-Surface Temperature','K','SSKSSTMP'],
    113'3':['Foundation Sea-Surface Temperature','K','FDNSSTMP'],
    114'4':['Estimated bias between Sea-Surface Temperature and Standard','K','EBSSTSTD'],
    115'5':['Estimated bias Standard Deviation between Sea-Surface Temperature and Standard','K','EBSDSSTS'],
    116'6-191':['Reserved','unknown','unknown'],
    117'192-254':['Reserved for Local Use','unknown','unknown'],
    118'255':['Missing','unknown','unknown'],
    119}
    120table_4_2_3_6  = {
    121'0':['Global Solar Irradiance','W m-2','GSOLIRR'],
    122'1':['Global Solar Exposure','J m-2','GSOLEXP'],
    123'2':['Direct Solar Irradiance','W m-2','DIRSOLIR'],
    124'3':['Direct Solar Exposure','J m-2','DIRSOLEX'],
    125'4':['Diffuse Solar Irradiance','W m-2','DIFSOLIR'],
    126'5':['Diffuse Solar Exposure','J m-2','DIFSOLEX'],
    127'6-191':['Reserved','unknown','unknown'],
    128'192-254':['Reserved for Local Use','unknown','unknown'],
    129'255':['Missing','unknown','unknown'],
    130}
    131table_4_2_3_192  = {
    132'0':['Simulated Brightness Temperature for GOES 12, Channel 2','K','SBT122'],
    133'1':['Simulated Brightness Temperature for GOES 12, Channel 3','K','SBT123'],
    134'2':['Simulated Brightness Temperature for GOES 12, Channel 4','K','SBT124'],
    135'3':['Simulated Brightness Temperature for GOES 12, Channel 6','K','SBT126'],
    136'4':['Simulated Brightness Counts for GOES 12, Channel 3','Byte','SBC123'],
    137'5':['Simulated Brightness Counts for GOES 12, Channel 4','Byte','SBC124'],
    138'6':['Simulated Brightness Temperature for GOES 11, Channel 2','K','SBT112'],
    139'7':['Simulated Brightness Temperature for GOES 11, Channel 3','K','SBT113'],
    140'8':['Simulated Brightness Temperature for GOES 11, Channel 4','K','SBT114'],
    141'9':['Simulated Brightness Temperature for GOES 11, Channel 5','K','SBT115'],
    142'10':['Simulated Brightness Temperature for AMSRE on Aqua, Channel 9','K','AMSRE9'],
    143'11':['Simulated Brightness Temperature for AMSRE on Aqua, Channel 10','K','AMSRE10'],
    144'12':['Simulated Brightness Temperature for AMSRE on Aqua, Channel 11','K','AMSRE11'],
    145'13':['Simulated Brightness Temperature for AMSRE on Aqua, Channel 12','K','AMSRE12'],
    146'14':['Simulated Reflectance Factor for ABI GOES-16, Band-1','unknown','SRFA161'],
    147'15':['Simulated Reflectance Factor for ABI GOES-16, Band-2','unknown','SRFA162'],
    148'16':['Simulated Reflectance Factor for ABI GOES-16, Band-3','unknown','SRFA163'],
    149'17':['Simulated Reflectance Factor for ABI GOES-16, Band-4','unknown','SRFA164'],
    150'18':['Simulated Reflectance Factor for ABI GOES-16, Band-5','unknown','SRFA165'],
    151'19':['Simulated Reflectance Factor for ABI GOES-16, Band-6','unknown','SRFA166'],
    152'20':['Simulated Brightness Temperature for ABI GOES-16, Band-7','K','SBTA167'],
    153'21':['Simulated Brightness Temperature for ABI GOES-16, Band-8','K','SBTA168'],
    154'22':['Simulated Brightness Temperature for ABI GOES-16, Band-9','K','SBTA169'],
    155'23':['Simulated Brightness Temperature for ABI GOES-16, Band-10','K','SBTA1610'],
    156'24':['Simulated Brightness Temperature for ABI GOES-16, Band-11','K','SBTA1611'],
    157'25':['Simulated Brightness Temperature for ABI GOES-16, Band-12','K','SBTA1612'],
    158'26':['Simulated Brightness Temperature for ABI GOES-16, Band-13','K','SBTA1613'],
    159'27':['Simulated Brightness Temperature for ABI GOES-16, Band-14','K','SBTA1614'],
    160'28':['Simulated Brightness Temperature for ABI GOES-16, Band-15','K','SBTA1615'],
    161'29':['Simulated Brightness Temperature for ABI GOES-16, Band-16','K','SBTA1616'],
    162'30':['Simulated Reflectance Factor for ABI GOES-17, Band-1','unknown','SRFA171'],
    163'31':['Simulated Reflectance Factor for ABI GOES-17, Band-2','unknown','SRFA172'],
    164'32':['Simulated Reflectance Factor for ABI GOES-17, Band-3','unknown','SRFA173'],
    165'33':['Simulated Reflectance Factor for ABI GOES-17, Band-4','unknown','SRFA174'],
    166'34':['Simulated Reflectance Factor for ABI GOES-17, Band-5','unknown','SRFA175'],
    167'35':['Simulated Reflectance Factor for ABI GOES-17, Band-6','unknown','SRFA176'],
    168'36':['Simulated Brightness Temperature for ABI GOES-17, Band-7','K','SBTA177'],
    169'37':['Simulated Brightness Temperature for ABI GOES-17, Band-8','K','SBTA178'],
    170'38':['Simulated Brightness Temperature for ABI GOES-17, Band-9','K','SBTA179'],
    171'39':['Simulated Brightness Temperature for ABI GOES-17, Band-10','K','SBTA1710'],
    172'40':['Simulated Brightness Temperature for ABI GOES-17, Band-11','K','SBTA1711'],
    173'41':['Simulated Brightness Temperature for ABI GOES-17, Band-12','K','SBTA1712'],
    174'42':['Simulated Brightness Temperature for ABI GOES-17, Band-13','K','SBTA1713'],
    175'43':['Simulated Brightness Temperature for ABI GOES-17, Band-14','K','SBTA1714'],
    176'44':['Simulated Brightness Temperature for ABI GOES-17, Band-15','K','SBTA1715'],
    177'45':['Simulated Brightness Temperature for ABI GOES-17, Band-16','K','SBTA1716'],
    178'46':['Simulated Reflectance Factor for nadir ABI GOES-R, Band-1','unknown','SRFAGR1'],
    179'47':['Simulated Reflectance Factor for nadir ABI GOES-R, Band-2','unknown','SRFAGR2'],
    180'48':['Simulated Reflectance Factor for nadir ABI GOES-R, Band-3','unknown','SRFAGR3'],
    181'49':['Simulated Reflectance Factor for nadir ABI GOES-R, Band-4','unknown','SRFAGR4'],
    182'50':['Simulated Reflectance Factor for nadir ABI GOES-R, Band-5','unknown','SRFAGR5'],
    183'51':['Simulated Reflectance Factor for nadir ABI GOES-R, Band-6','unknown','SRFAGR6'],
    184'52':['Simulated Brightness Temperature for nadir ABI GOES-R, Band-7','unknown','SBTAGR7'],
    185'53':['Simulated Brightness Temperature for nadir ABI GOES-R, Band-8','unknown','SBTAGR8'],
    186'54':['Simulated Brightness Temperature for nadir ABI GOES-R, Band-9','unknown','SBTAGR9'],
    187'55':['Simulated Brightness Temperature for nadir ABI GOES-R, Band-10','unknown','SBTAGR10'],
    188'56':['Simulated Brightness Temperature for nadir ABI GOES-R, Band-11','unknown','SBTAGR11'],
    189'57':['Simulated Brightness Temperature for nadir ABI GOES-R, Band-12','unknown','SBTAGR12'],
    190'58':['Simulated Brightness Temperature for nadir ABI GOES-R, Band-13','unknown','SBTAGR13'],
    191'59':['Simulated Brightness Temperature for nadir ABI GOES-R, Band-14','unknown','SBTAGR14'],
    192'60':['Simulated Brightness Temperature for nadir ABI GOES-R, Band-15','unknown','SBTAGR15'],
    193'61':['Simulated Brightness Temperature for nadir ABI GOES-R, Band-16','unknown','SBTAGR16'],
    194'62':['Simulated Brightness Temperature for SSMIS-F17, Channel 15','K','SSMS1715'],
    195'63':['Simulated Brightness Temperature for SSMIS-F17, Channel 16','K','SSMS1716'],
    196'64':['Simulated Brightness Temperature for SSMIS-F17, Channel 17','K','SSMS1717'],
    197'65':['Simulated Brightness Temperature for SSMIS-F17, Channel 18','K','SSMS1718'],
    198'66':['Simulated Brightness Temperature for Himawari-8, Band-7','K','SBTAHI7'],
    199'67':['Simulated Brightness Temperature for Himawari-8, Band-8','K','SBTAHI8'],
    200'68':['Simulated Brightness Temperature for Himawari-8, Band-9','K','SBTAHI9'],
    201'69':['Simulated Brightness Temperature for Himawari-8, Band-10','K','SBTAHI10'],
    202'70':['Simulated Brightness Temperature for Himawari-8, Band-11','K','SBTAHI11'],
    203'71':['Simulated Brightness Temperature for Himawari-8, Band-12','K','SBTAHI12'],
    204'72':['Simulated Brightness Temperature for Himawari-8, Band-13','K','SBTAHI13'],
    205'73':['Simulated Brightness Temperature for Himawari-8, Band-14','K','SBTAHI14'],
    206'74':['Simulated Brightness Temperature for Himawari-8, Band-15','K','SBTAHI15'],
    207'75':['Simulated Brightness Temperature for Himawari-8, Band-16','K','SBTAHI16'],
    208'76':['Simulated Brightness Temperature for ABI GOES-18, Band-7','K','SBTA187'],
    209'77':['Simulated Brightness Temperature for ABI GOES-18, Band-8','K','SBTA188'],
    210'78':['Simulated Brightness Temperature for ABI GOES-18, Band-9','K','SBTA189'],
    211'79':['Simulated Brightness Temperature for ABI GOES-18, Band-10','K','SBTA1810'],
    212'80':['Simulated Brightness Temperature for ABI GOES-18, Band-11','K','SBTA1811'],
    213'81':['Simulated Brightness Temperature for ABI GOES-18, Band-12','K','SBTA1812'],
    214'82':['Simulated Brightness Temperature for ABI GOES-18, Band-13','K','SBTA1813'],
    215'83':['Simulated Brightness Temperature for ABI GOES-18, Band-14','K','SBTA1814'],
    216'84':['Simulated Brightness Temperature for ABI GOES-18, Band-15','K','SBTA1815'],
    217'85':['Simulated Brightness Temperature for ABI GOES-18, Band-16','K','SBTA1816'],
    218'86':['Simulated Brightness Temperature for SSMIS-F17, Channel 12','K','SSMS1712'],
    219'87':['Simulated Brightness Temperature for SSMIS-F17, Channel 13','K','SSMS1713'],
    220'88-191':['Reserved','unknown','unknown'],
    221'192-254':['Reserved for Local Use','unknown','unknown'],
    222'255':['Missing','unknown','unknown'],
    223}

table_4_2_3_0 = {'0': ['Scaled Radiance', 'Numeric', 'SRAD'], '1': ['Scaled Albedo', 'Numeric', 'SALBEDO'], '2': ['Scaled Brightness Temperature', 'Numeric', 'SBTMP'], '3': ['Scaled Precipitable Water', 'Numeric', 'SPWAT'], '4': ['Scaled Lifted Index', 'Numeric', 'SLFTI'], '5': ['Scaled Cloud Top Pressure', 'Numeric', 'SCTPRES'], '6': ['Scaled Skin Temperature', 'Numeric', 'SSTMP'], '7': ['Cloud Mask', 'See Table 4.217', 'CLOUDM'], '8': ['Pixel scene type', 'See Table 4.218', 'PIXST'], '9': ['Fire Detection Indicator', 'See Table 4.223', 'FIREDI'], '10-191': ['Reserved', 'unknown', 'unknown'], '192-254': ['Reserved for Local Use', 'unknown', 'unknown'], '255': ['Missing', 'unknown', 'unknown']}
table_4_2_3_1 = {'0': ['Estimated Precipitation', 'kg m-2', 'ESTP'], '1': ['Instantaneous Rain Rate', 'kg m-2 s-1', 'IRRATE'], '2': ['Cloud Top Height', 'm', 'CTOPH'], '3': ['Cloud Top Height Quality Indicator', 'Code table 4.219', 'CTOPHQI'], '4': ['Estimated u-Component of Wind', 'm s-1', 'ESTUGRD'], '5': ['Estimated v-Component of Wind', 'm s-1', 'ESTVGRD'], '6': ['Number Of Pixels Used', 'Numeric', 'NPIXU'], '7': ['Solar Zenith Angle', '°', 'SOLZA'], '8': ['Relative Azimuth Angle', '°', 'RAZA'], '9': ['Reflectance in 0.6 Micron Channel', '%', 'RFL06'], '10': ['Reflectance in 0.8 Micron Channel', '%', 'RFL08'], '11': ['Reflectance in 1.6 Micron Channel', '%', 'RFL16'], '12': ['Reflectance in 3.9 Micron Channel', '%', 'RFL39'], '13': ['Atmospheric Divergence', 's-1', 'ATMDIV'], '14': ['Cloudy Brightness Temperature', 'K', 'CBTMP'], '15': ['Clear Sky Brightness Temperature', 'K', 'CSBTMP'], '16': ['Cloudy Radiance (with respect to wave number)', 'W m-1 sr-1', 'CLDRAD'], '17': ['Clear Sky Radiance (with respect to wave number)', 'W m-1 sr-1', 'CSKYRAD'], '18': ['Reserved', 'unknown', 'unknown'], '19': ['Wind Speed', 'm s-1', 'WINDS'], '20': ['Aerosol Optical Thickness at 0.635 µm', 'unknown', 'AOT06'], '21': ['Aerosol Optical Thickness at 0.810 µm', 'unknown', 'AOT08'], '22': ['Aerosol Optical Thickness at 1.640 µm', 'unknown', 'AOT16'], '23': ['Angstrom Coefficient', 'unknown', 'ANGCOE'], '24-26': ['Reserved', 'unknown', 'unknown'], '27': ['Bidirectional Reflecance Factor', 'Numeric', 'BRFLF'], '28': ['Brightness Temperature', 'K', 'SPBRT'], '29': ['Scaled Radiance', 'Numeric', 'SCRAD'], '30': ['Reflectance in 0.4 Micron Channel', '%', 'RFL04'], '31': ['Cloudy reflectance', '%', 'CLDREF'], '32': ['Clear reflectance', '%', 'CLRREF'], '33-97': ['Reserved', 'unknown', 'unknown'], '98': ['Correlation coefficient between MPE rain rates for the co-located IR data and the microwave data rain rates', 'Numeric', 'CCMPEMRR'], '99': ['Standard deviation between MPE rain rates for the co-located IR data and the microwave data rain rates', 'Numeric', 'SDMPEMRR'], '100-191': ['Reserved', 'unknown', 'unknown'], '192-254': ['Reserved for Local Use', 'unknown', 'unknown'], '192': ['Scatterometer Estimated U Wind Component', 'm s-1', 'USCT'], '193': ['Scatterometer Estimated V Wind Component', 'm s-1', 'VSCT'], '194': ['Scatterometer Wind Quality', 'unknown', 'SWQI'], '255': ['Missing', 'unknown', 'unknown']}
table_4_2_3_2 = {'0': ['Clear Sky Probability', '%', 'CSKPROB'], '1': ['Cloud Top Temperature', 'K', 'CTOPTMP'], '2': ['Cloud Top Pressure', 'Pa', 'CTOPRES'], '3': ['Cloud Type', 'See Table 4.218', 'CLDTYPE'], '4': ['Cloud Phase', 'See Table 4.218', 'CLDPHAS'], '5': ['Cloud Optical Depth', 'Numeric', 'CLDODEP'], '6': ['Cloud Particle Effective Radius', 'm', 'CLDPER'], '7': ['Cloud Liquid Water Path', 'kg m-2', 'CLDLWP'], '8': ['Cloud Ice Water Path', 'kg m-2', 'CLDIWP'], '9': ['Cloud Albedo', 'Numeric', 'CLDALB'], '10': ['Cloud Emissivity', 'Numeric', 'CLDEMISS'], '11': ['Effective Absorption Optical Depth Ratio', 'Numeric', 'EAODR'], '12-29': ['Reserved', 'unknown', 'unknown'], '30': ['Measurement cost', 'Numeric', 'MEACST'], '31': ['Upper layer cloud optical depth (see Note)', 'Numeric', 'unknown'], '32': ['Upper layer cloud top pressure (see Note)', 'Pa', 'unknown'], '33': ['Upper layer cloud effective radius (see Note)', 'm', 'unknown'], '34': ['Error in upper layer cloud optical depth(se Note)', 'Numeric', 'unknown'], '35': ['Error in upper layer cloud top pressure (see Note)', 'Pa', 'unknown'], '36': ['Error in upper layer cloud effective radius (see Note)', 'm', 'unknown'], '37': ['Lower layer cloud optical depth (see Note)', 'Numeric', 'unknown'], '38': ['Lower layer cloud top pressure (see Note)', 'Pa', 'unknown'], '39': ['Error in lower layer cloud optical depth (see Note)', 'Numeric', 'unknown'], '40': ['Error in lower layer cloud top pressure (see Note)', 'Pa', 'unknown'], '41-191': ['Reserved', 'unknown', 'unknown'], '192-254': ['Reserved for Local Use', 'unknown', 'unknown'], '255': ['Missing', 'unknown', 'unknown']}
table_4_2_3_3 = {'0': ['Probability of Encountering Marginal Visual Flight Rules Conditions', '%', 'PBMVFRC'], '1': ['Probability of Encountering Low Instrument Flight Rules Conditions', '%', 'PBLIFRC'], '2': ['Probability of Encountering Instrument Flight Rules Conditions', '%', 'PBINFRC'], '3-191': ['Reserved', 'unknown', 'unknown'], '192-254': ['Reserved for Local Use', 'unknown', 'unknown'], '255': ['Missing', 'unknown', 'unknown']}
table_4_2_3_4 = {'0': ['Volcanic Ash Probability', '%', 'VOLAPROB'], '1': ['Volcanic Ash Cloud Top Temperature', 'K', 'VOLACDTT'], '2': ['Volcanic Ash Cloud Top Pressure', 'Pa', 'VOLACDTP'], '3': ['Volcanic Ash Cloud Top Height', 'm', 'VOLACDTH'], '4': ['Volcanic Ash Cloud Emissity', 'Numeric', 'VOLACDEM'], '5': ['Volcanic Ash Effective Absorption Depth Ratio', 'Numeric', 'VOLAEADR'], '6': ['Volcanic Ash Cloud Optical Depth', 'Numeric', 'VOLACDOD'], '7': ['Volcanic Ash Column Density', 'kg m-2', 'VOLACDEN'], '8': ['Volcanic Ash Particle Effective Radius', 'm', 'VOLAPER'], '9-191': ['Reserved', 'unknown', 'unknown'], '192-254': ['Reserved for Local Use', 'unknown', 'unknown'], '255': ['Missing', 'unknown', 'unknown']}
table_4_2_3_5 = {'0': ['Interface Sea-Surface Temperature', 'K', 'ISSTMP'], '1': ['Skin Sea-Surface Temperature', 'K', 'SKSSTMP'], '2': ['Sub-Skin Sea-Surface Temperature', 'K', 'SSKSSTMP'], '3': ['Foundation Sea-Surface Temperature', 'K', 'FDNSSTMP'], '4': ['Estimated bias between Sea-Surface Temperature and Standard', 'K', 'EBSSTSTD'], '5': ['Estimated bias Standard Deviation between Sea-Surface Temperature and Standard', 'K', 'EBSDSSTS'], '6-191': ['Reserved', 'unknown', 'unknown'], '192-254': ['Reserved for Local Use', 'unknown', 'unknown'], '255': ['Missing', 'unknown', 'unknown']}
table_4_2_3_6 = {'0': ['Global Solar Irradiance', 'W m-2', 'GSOLIRR'], '1': ['Global Solar Exposure', 'J m-2', 'GSOLEXP'], '2': ['Direct Solar Irradiance', 'W m-2', 'DIRSOLIR'], '3': ['Direct Solar Exposure', 'J m-2', 'DIRSOLEX'], '4': ['Diffuse Solar Irradiance', 'W m-2', 'DIFSOLIR'], '5': ['Diffuse Solar Exposure', 'J m-2', 'DIFSOLEX'], '6-191': ['Reserved', 'unknown', 'unknown'], '192-254': ['Reserved for Local Use', 'unknown', 'unknown'], '255': ['Missing', 'unknown', 'unknown']}
table_4_2_3_192 = {'0': ['Simulated Brightness Temperature for GOES 12, Channel 2', 'K', 'SBT122'], '1': ['Simulated Brightness Temperature for GOES 12, Channel 3', 'K', 'SBT123'], '2': ['Simulated Brightness Temperature for GOES 12, Channel 4', 'K', 'SBT124'], '3': ['Simulated Brightness Temperature for GOES 12, Channel 6', 'K', 'SBT126'], '4': ['Simulated Brightness Counts for GOES 12, Channel 3', 'Byte', 'SBC123'], '5': ['Simulated Brightness Counts for GOES 12, Channel 4', 'Byte', 'SBC124'], '6': ['Simulated Brightness Temperature for GOES 11, Channel 2', 'K', 'SBT112'], '7': ['Simulated Brightness Temperature for GOES 11, Channel 3', 'K', 'SBT113'], '8': ['Simulated Brightness Temperature for GOES 11, Channel 4', 'K', 'SBT114'], '9': ['Simulated Brightness Temperature for GOES 11, Channel 5', 'K', 'SBT115'], '10': ['Simulated Brightness Temperature for AMSRE on Aqua, Channel 9', 'K', 'AMSRE9'], '11': ['Simulated Brightness Temperature for AMSRE on Aqua, Channel 10', 'K', 'AMSRE10'], '12': ['Simulated Brightness Temperature for AMSRE on Aqua, Channel 11', 'K', 'AMSRE11'], '13': ['Simulated Brightness Temperature for AMSRE on Aqua, Channel 12', 'K', 'AMSRE12'], '14': ['Simulated Reflectance Factor for ABI GOES-16, Band-1', 'unknown', 'SRFA161'], '15': ['Simulated Reflectance Factor for ABI GOES-16, Band-2', 'unknown', 'SRFA162'], '16': ['Simulated Reflectance Factor for ABI GOES-16, Band-3', 'unknown', 'SRFA163'], '17': ['Simulated Reflectance Factor for ABI GOES-16, Band-4', 'unknown', 'SRFA164'], '18': ['Simulated Reflectance Factor for ABI GOES-16, Band-5', 'unknown', 'SRFA165'], '19': ['Simulated Reflectance Factor for ABI GOES-16, Band-6', 'unknown', 'SRFA166'], '20': ['Simulated Brightness Temperature for ABI GOES-16, Band-7', 'K', 'SBTA167'], '21': ['Simulated Brightness Temperature for ABI GOES-16, Band-8', 'K', 'SBTA168'], '22': ['Simulated Brightness Temperature for ABI GOES-16, Band-9', 'K', 'SBTA169'], '23': ['Simulated Brightness Temperature for ABI GOES-16, Band-10', 'K', 'SBTA1610'], '24': ['Simulated Brightness Temperature for ABI GOES-16, Band-11', 'K', 'SBTA1611'], '25': ['Simulated Brightness Temperature for ABI GOES-16, Band-12', 'K', 'SBTA1612'], '26': ['Simulated Brightness Temperature for ABI GOES-16, Band-13', 'K', 'SBTA1613'], '27': ['Simulated Brightness Temperature for ABI GOES-16, Band-14', 'K', 'SBTA1614'], '28': ['Simulated Brightness Temperature for ABI GOES-16, Band-15', 'K', 'SBTA1615'], '29': ['Simulated Brightness Temperature for ABI GOES-16, Band-16', 'K', 'SBTA1616'], '30': ['Simulated Reflectance Factor for ABI GOES-17, Band-1', 'unknown', 'SRFA171'], '31': ['Simulated Reflectance Factor for ABI GOES-17, Band-2', 'unknown', 'SRFA172'], '32': ['Simulated Reflectance Factor for ABI GOES-17, Band-3', 'unknown', 'SRFA173'], '33': ['Simulated Reflectance Factor for ABI GOES-17, Band-4', 'unknown', 'SRFA174'], '34': ['Simulated Reflectance Factor for ABI GOES-17, Band-5', 'unknown', 'SRFA175'], '35': ['Simulated Reflectance Factor for ABI GOES-17, Band-6', 'unknown', 'SRFA176'], '36': ['Simulated Brightness Temperature for ABI GOES-17, Band-7', 'K', 'SBTA177'], '37': ['Simulated Brightness Temperature for ABI GOES-17, Band-8', 'K', 'SBTA178'], '38': ['Simulated Brightness Temperature for ABI GOES-17, Band-9', 'K', 'SBTA179'], '39': ['Simulated Brightness Temperature for ABI GOES-17, Band-10', 'K', 'SBTA1710'], '40': ['Simulated Brightness Temperature for ABI GOES-17, Band-11', 'K', 'SBTA1711'], '41': ['Simulated Brightness Temperature for ABI GOES-17, Band-12', 'K', 'SBTA1712'], '42': ['Simulated Brightness Temperature for ABI GOES-17, Band-13', 'K', 'SBTA1713'], '43': ['Simulated Brightness Temperature for ABI GOES-17, Band-14', 'K', 'SBTA1714'], '44': ['Simulated Brightness Temperature for ABI GOES-17, Band-15', 'K', 'SBTA1715'], '45': ['Simulated Brightness Temperature for ABI GOES-17, Band-16', 'K', 'SBTA1716'], '46': ['Simulated Reflectance Factor for nadir ABI GOES-R, Band-1', 'unknown', 'SRFAGR1'], '47': ['Simulated Reflectance Factor for nadir ABI GOES-R, Band-2', 'unknown', 'SRFAGR2'], '48': ['Simulated Reflectance Factor for nadir ABI GOES-R, Band-3', 'unknown', 'SRFAGR3'], '49': ['Simulated Reflectance Factor for nadir ABI GOES-R, Band-4', 'unknown', 'SRFAGR4'], '50': ['Simulated Reflectance Factor for nadir ABI GOES-R, Band-5', 'unknown', 'SRFAGR5'], '51': ['Simulated Reflectance Factor for nadir ABI GOES-R, Band-6', 'unknown', 'SRFAGR6'], '52': ['Simulated Brightness Temperature for nadir ABI GOES-R, Band-7', 'unknown', 'SBTAGR7'], '53': ['Simulated Brightness Temperature for nadir ABI GOES-R, Band-8', 'unknown', 'SBTAGR8'], '54': ['Simulated Brightness Temperature for nadir ABI GOES-R, Band-9', 'unknown', 'SBTAGR9'], '55': ['Simulated Brightness Temperature for nadir ABI GOES-R, Band-10', 'unknown', 'SBTAGR10'], '56': ['Simulated Brightness Temperature for nadir ABI GOES-R, Band-11', 'unknown', 'SBTAGR11'], '57': ['Simulated Brightness Temperature for nadir ABI GOES-R, Band-12', 'unknown', 'SBTAGR12'], '58': ['Simulated Brightness Temperature for nadir ABI GOES-R, Band-13', 'unknown', 'SBTAGR13'], '59': ['Simulated Brightness Temperature for nadir ABI GOES-R, Band-14', 'unknown', 'SBTAGR14'], '60': ['Simulated Brightness Temperature for nadir ABI GOES-R, Band-15', 'unknown', 'SBTAGR15'], '61': ['Simulated Brightness Temperature for nadir ABI GOES-R, Band-16', 'unknown', 'SBTAGR16'], '62': ['Simulated Brightness Temperature for SSMIS-F17, Channel 15', 'K', 'SSMS1715'], '63': ['Simulated Brightness Temperature for SSMIS-F17, Channel 16', 'K', 'SSMS1716'], '64': ['Simulated Brightness Temperature for SSMIS-F17, Channel 17', 'K', 'SSMS1717'], '65': ['Simulated Brightness Temperature for SSMIS-F17, Channel 18', 'K', 'SSMS1718'], '66': ['Simulated Brightness Temperature for Himawari-8, Band-7', 'K', 'SBTAHI7'], '67': ['Simulated Brightness Temperature for Himawari-8, Band-8', 'K', 'SBTAHI8'], '68': ['Simulated Brightness Temperature for Himawari-8, Band-9', 'K', 'SBTAHI9'], '69': ['Simulated Brightness Temperature for Himawari-8, Band-10', 'K', 'SBTAHI10'], '70': ['Simulated Brightness Temperature for Himawari-8, Band-11', 'K', 'SBTAHI11'], '71': ['Simulated Brightness Temperature for Himawari-8, Band-12', 'K', 'SBTAHI12'], '72': ['Simulated Brightness Temperature for Himawari-8, Band-13', 'K', 'SBTAHI13'], '73': ['Simulated Brightness Temperature for Himawari-8, Band-14', 'K', 'SBTAHI14'], '74': ['Simulated Brightness Temperature for Himawari-8, Band-15', 'K', 'SBTAHI15'], '75': ['Simulated Brightness Temperature for Himawari-8, Band-16', 'K', 'SBTAHI16'], '76': ['Simulated Brightness Temperature for ABI GOES-18, Band-7', 'K', 'SBTA187'], '77': ['Simulated Brightness Temperature for ABI GOES-18, Band-8', 'K', 'SBTA188'], '78': ['Simulated Brightness Temperature for ABI GOES-18, Band-9', 'K', 'SBTA189'], '79': ['Simulated Brightness Temperature for ABI GOES-18, Band-10', 'K', 'SBTA1810'], '80': ['Simulated Brightness Temperature for ABI GOES-18, Band-11', 'K', 'SBTA1811'], '81': ['Simulated Brightness Temperature for ABI GOES-18, Band-12', 'K', 'SBTA1812'], '82': ['Simulated Brightness Temperature for ABI GOES-18, Band-13', 'K', 'SBTA1813'], '83': ['Simulated Brightness Temperature for ABI GOES-18, Band-14', 'K', 'SBTA1814'], '84': ['Simulated Brightness Temperature for ABI GOES-18, Band-15', 'K', 'SBTA1815'], '85': ['Simulated Brightness Temperature for ABI GOES-18, Band-16', 'K', 'SBTA1816'], '86': ['Simulated Brightness Temperature for SSMIS-F17, Channel 12', 'K', 'SSMS1712'], '87': ['Simulated Brightness Temperature for SSMIS-F17, Channel 13', 'K', 'SSMS1713'], '88-191': ['Reserved', 'unknown', 'unknown'], '192-254': ['Reserved for Local Use', 'unknown', 'unknown'], '255': ['Missing', 'unknown', 'unknown']}